==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/IBMCloudPlatformStatusFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface IBMCloudPlatformStatusFluent<A extends io.fabric8.openshift.api.model.IBMCloudPlatformStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getLocation();
  public A withLocation(java.lang.String location);
  public java.lang.Boolean hasLocation();
  
  /**
   * Method is deprecated. use withLocation instead.
   */
  @java.lang.Deprecated
  public A withNewLocation(java.lang.String arg0);
  public java.lang.String getProviderType();
  public A withProviderType(java.lang.String providerType);
  public java.lang.Boolean hasProviderType();
  
  /**
   * Method is deprecated. use withProviderType instead.
   */
  @java.lang.Deprecated
  public A withNewProviderType(java.lang.String arg0);
  public java.lang.String getResourceGroupName();
  public A withResourceGroupName(java.lang.String resourceGroupName);
  public java.lang.Boolean hasResourceGroupName();
  
  /**
   * Method is deprecated. use withResourceGroupName instead.
   */
  @java.lang.Deprecated
  public A withNewResourceGroupName(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/IBMCloudPlatformStatusFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface IBMCloudPlatformStatusFluent<A extends io.fabric8.openshift.api.model.IBMCloudPlatformStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getCisInstanceCRN();
  public A withCisInstanceCRN(java.lang.String cisInstanceCRN);
  public java.lang.Boolean hasCisInstanceCRN();
  
  /**
   * Method is deprecated. use withCisInstanceCRN instead.
   */
  @java.lang.Deprecated
  public A withNewCisInstanceCRN(java.lang.String arg0);
  public java.lang.String getLocation();
  public A withLocation(java.lang.String location);
  public java.lang.Boolean hasLocation();
  
  /**
   * Method is deprecated. use withLocation instead.
   */
  @java.lang.Deprecated
  public A withNewLocation(java.lang.String arg0);
  public java.lang.String getProviderType();
  public A withProviderType(java.lang.String providerType);
  public java.lang.Boolean hasProviderType();
  
  /**
   * Method is deprecated. use withProviderType instead.
   */
  @java.lang.Deprecated
  public A withNewProviderType(java.lang.String arg0);
  public java.lang.String getResourceGroupName();
  public A withResourceGroupName(java.lang.String resourceGroupName);
  public java.lang.Boolean hasResourceGroupName();
  
  /**
   * Method is deprecated. use withResourceGroupName instead.
   */
  @java.lang.Deprecated
  public A withNewResourceGroupName(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
